/* schema.h   schema (struct) of LINEITEM relation from 
 *            TPC-H Benchmark Specification 2.8.0, page 15 
 *            (c) ETH Zurich 2009, Rene Mueller
 *            $Id: schema.h 225 2009-10-05 07:35:25Z muellren $
 */

#ifndef SCHEMA_H
#define SCHEMA_H

/* type mapping according to the TPC-H Benchmark 
 * specification 2.8.0, page 13:
 *
 * identifier: supports at least 2,147,483,647 unique values => 32 bit
 * integer:    -2,147,483,646 to 2,147,483,647 => signed 32 bit
 * decimal:    -9,999,999,999.99 to 9,999,999,999.99 => int64_t
 *              (representation in 100ths)
 * date:       YYYY-MM-DD using 32-bit representation 
 *             10,0000*YYYY + 100*MM + DD
 * varchar:    represented as fixed length string
 */

/* LINEITEM Schema adapted from the
 * TPC-H Benchmark Specification 2.8.0, page 15 */
typedef struct {
   uint32_t orderkey;         /* identifier */
   uint32_t partkey;          /* identifier */
   uint32_t suppkey;          /* identifier */
   int64_t  quantity;         /* decimal */
   int64_t  extendedprice;    /* decimal */
   int64_t  discount;         /* decimal */
   int64_t  tax;              /* decimal */
   char     returnflag;       /* fixed text, size 1 */
   char     linestatus;       /* fixed text, size 1 */
   uint32_t commitdate;       /* date */
   uint32_t receiptdate;      /* date */
   char     shipinstruct[26]; /* fixed text, size 25 */
   int32_t  linenumber;       /* integer */
   char     shipmode[11];     /* fixed text, size 10 */
   char     comment[45];      /* variable text, size 44 */
   uint32_t shipdate;         /* date */
} lineitem_t;

#define NUM_ATTRIBUTES 16
typedef enum { 
   L_ORDERKEY=0, L_PARTKEY, L_SUPPKEY, L_LINENUMBER, 
   L_QUANTITY, L_EXTENDEDPRICE, L_DISCOUNT, L_TAX,
   L_RETURNFLAG, L_LINESTATUS, L_SHIPDATE, L_COMMITDATE,
   L_RECEIPTDATE, L_SHIPINSTRUCT, L_SHIPMODE, L_COMMENT
} attributes_t;

/* .tbl fine containing all input data */
#define DATA_FILE    "lineitem.tbl"


#ifdef DEBUG
static void printrow(lineitem_t *row)
{
   printf("orderkey:       %u\n", row->orderkey);
   printf("partkey:        %u\n", row->partkey);
   printf("suppkey:        %u\n", row->suppkey);
   printf("linenumber:     %d\n", row->linenumber);
   printf("quantity:       %lld\n", row->quantity);
   printf("extendedprice:  %lld\n", row->extendedprice);
   printf("discount:       %lld\n", row->discount);
   printf("tax:            %lld\n", row->tax);
   printf("returnflag:     %c\n", row->returnflag);
   printf("linestatus:     %c\n", row->linestatus);
   printf("shipdate:       %.08d\n", row->shipdate);
   printf("commitdate:     %.08d\n", row->commitdate);
   printf("receiptdate:    %.08d\n", row->receiptdate);
   printf("shipinstruct:   %s\n", row->shipinstruct);
   printf("shipmode:       %s\n", row->shipmode);
   printf("comment:        %s\n", row->comment); 
}
#endif // DEBUG


#endif // SCHEMA_H
